@@ -95,7 +95,11 @@ QStringList VFolderMenu::allDirectories()
    QString previous = *it++;
    for(;it != m_allDirectories.end();)
    {
+#ifndef Q_OS_WIN
      if ((*it).startsWith(previous))
+#else
+     if ((*it).startsWith(previous, Qt::CaseInsensitive))
+#endif
      {
         it = m_allDirectories.erase(it);
      }
@@ -373,11 +377,7 @@ VFolderMenu::buildApplicationIndex(bool unusedOnly)
             continue;
          }
 
-         const QStringList cats = s->categories();
-         for(QStringList::ConstIterator it2 = cats.begin();
-             it2 != cats.end(); ++it2)
-         {
-            const QString &cat = *it2;
+         Q_FOREACH(const QString& cat, s->categories()) {
             info->dictCategories[cat].append(s); // find or insert entry in hash
          }
       }
@@ -435,12 +435,14 @@ VFolderMenu::absoluteDir(const QString &_dir, const QString &baseDir, bool keepR
    if (!dir.endsWith('/'))
       dir += '/';
 
-   if (QDir::isRelativePath(dir) && !keepRelativeToCfg)
-   {
+   bool relative = QDir::isRelativePath(dir);
+   if (relative && !keepRelativeToCfg) {
+      relative = false;
       dir = KGlobal::dirs()->findResource("xdgconf-menu", dir);
    }
 
-   dir = KGlobal::dirs()->realPath(dir);
+   if (!relative)
+      dir = KGlobal::dirs()->realPath(dir);
 
    return dir;
 }
@@ -1270,7 +1272,11 @@ kDebug(7021) << "Processing KDE Legacy dirs for <KDE>";
 
             QString prefix = e.attributes().namedItem("prefix").toAttr().value();
 
+#ifndef Q_OS_WIN
             if (m_defaultLegacyDirs.contains(dir))
+#else
+            if (m_defaultLegacyDirs.contains(dir, Qt::CaseInsensitive))
+#endif
             {
                if (!kdeLegacyDirsDone)
                {
