@@ -38,7 +38,6 @@
 
 #include <kapplication.h>
 #include <kauthorized.h>
-#include <klibloader.h>
 #include <kaboutdata.h>
 #include <klocale.h>
 #include <kstatusbar.h>
@@ -48,7 +47,7 @@
 #include <kio/authinfo.h>
 
 
-K_EXPORT_COMPONENT_FACTORY (kjavaappletviewer, KJavaAppletViewerFactory)
+K_EXPORT_PLUGIN( KJavaAppletViewerFactory )
 
 KComponentData *KJavaAppletViewerFactory::s_componentData = 0;
 KIconLoader *KJavaAppletViewerFactory::s_iconLoader = 0;
@@ -63,10 +62,12 @@ KJavaAppletViewerFactory::~KJavaAppletViewerFactory () {
     delete s_componentData;
 }
 
-KParts::Part *KJavaAppletViewerFactory::createPartObject
-  (QWidget *wparent,
-   QObject *parent, const char *, const QStringList & args) {
-    return new KJavaAppletViewer (wparent, parent, args);
+QObject *KJavaAppletViewerFactory::create(const char *, QWidget *wparent, QObject *parent,
+                                          const QVariantList & args, const QString &) {
+    QStringList argsStrings;
+    for (int i = 0; i < args.size(); ++i)
+        argsStrings.append(args[i].toString());
+    return new KJavaAppletViewer (wparent, parent, argsStrings);
 }
 
 //-----------------------------------------------------------------------------
@@ -365,9 +366,9 @@ KJavaAppletViewer::KJavaAppletViewer (QWidget * wparent,
     KParts::Part::setWidget (m_view);
 
     connect (applet->getContext(), SIGNAL(appletLoaded()), this, SLOT(appletLoaded()));
-    connect (applet->getContext(), SIGNAL(showDocument(const QString&, const QString&)), m_browserextension, SLOT(showDocument(const QString&, const QString&)));
-    connect (applet->getContext(), SIGNAL(showStatus(const QString &)), this, SLOT(infoMessage(const QString &)));
-    connect (applet, SIGNAL(jsEvent (const QStringList &)), m_liveconnect, SLOT(jsEvent (const QStringList &)));
+    connect (applet->getContext(), SIGNAL(showDocument(QString,QString)), m_browserextension, SLOT(showDocument(QString,QString)));
+    connect (applet->getContext(), SIGNAL(showStatus(QString)), this, SLOT(infoMessage(QString)));
+    connect (applet, SIGNAL(jsEvent(QStringList)), m_liveconnect, SLOT(jsEvent(QStringList)));
 }
 
 CoverWidget * KJavaAppletViewer::view () const
@@ -427,7 +428,7 @@ bool KJavaAppletViewer::openUrl (const KUrl & url) {
     if (applet->size().width() > 0 || m_view->isVisible())
         w->showApplet ();
     else
-        QTimer::singleShot (10, this, SLOT (delayedCreateTimeOut ()));
+        QTimer::singleShot (10, this, SLOT (delayedCreateTimeOut()));
     if (!applet->failed ())
         emit started (0L);
     return url.isValid ();
